@@ -9,9 +9,7 @@ def get_logger(level: str):
         level=level,
         format="%(message)s",
         datefmt="[%X]",
-        handlers=[RichHandler(rich_tracebacks=True)]
+        handlers=[RichHandler(rich_tracebacks=True)],
     )
     logger = logging.getLogger("rich")
     return logger
-
-
