@@ -54,9 +54,7 @@ progress = Progress(
     "•",
     TextColumn("[bold]{task.fields[user]}", justify="left"),
     "•",
-    TextColumn(
-        "[bold dark_goldenrod]{task.fields[organisation]}", justify="left"
-    ),
+    TextColumn("[bold dark_goldenrod]{task.fields[organisation]}", justify="left"),
     "•",
     TimeRemainingColumn(),
     console=console,
@@ -112,10 +110,7 @@ class ProgressTask(ProgressInfo):
 
     @property
     def kwargs(self) -> Dict:
-        d = {
-            field_name: getattr(self, field_name)
-            for field_name in self._kwarg_fields
-        }
+        d = {field_name: getattr(self, field_name) for field_name in self._kwarg_fields}
         return {k: v for k, v in d.items() if not k.startswith("_")}
 
 
@@ -186,9 +181,7 @@ class ActiveSimulations:
         if color:
             status_txt = f"[bold {color}]{status_txt}[/bold {color}]"
         update_kwargs = {"status": status_txt}
-        advance_by = (
-            100 if status in ("finished", "ended", "postprocessing") else None
-        )
+        advance_by = 100 if status in ("finished", "ended", "postprocessing") else None
         if advance_by and not progress_task.task.started:
             progress.start_task(progress_task.task.id)
             update_kwargs.update({"advance": advance_by})
@@ -199,14 +192,10 @@ class ActiveSimulations:
 
     async def run_monitor(self) -> NoReturn:
 
-        asyncio.ensure_future(
-            self.websocket_client.listen("active-simulations/")
-        )
+        asyncio.ensure_future(self.websocket_client.listen("active-simulations/"))
         q = self.websocket_client.get_queue()
         try:
-            await asyncio.wait_for(
-                self.websocket_client.is_connected(), timeout=10
-            )
+            await asyncio.wait_for(self.websocket_client.is_connected(), timeout=10)
         except asyncio.TimeoutError:
             console.print("Could not establish WS connection", style="error")
             return
@@ -220,9 +209,7 @@ class ActiveSimulations:
                 if not message_type:
                     continue
                 if message_type == MessageTypes.initial:
-                    progress_tasks = await self.get_initial_progress_tasks(
-                        data
-                    )
+                    progress_tasks = await self.get_initial_progress_tasks(data)
                     for progress_task in progress_tasks:
                         await self.add_progress_bar(progress_task, progress)
                 elif message_type == MessageTypes.progress:
@@ -249,14 +236,10 @@ class ActiveSimulations:
         data = data["data"]
         simulation_id = list(data.keys())[0]
         data_json = list(data.values())[0]
-        return await ActiveSimulations._get_progress_task(
-            simulation_id, data_json
-        )
+        return await ActiveSimulations._get_progress_task(simulation_id, data_json)
 
     @staticmethod
-    async def _get_progress_task(
-        simulation_id, simulation_details
-    ) -> ProgressTask:
+    async def _get_progress_task(simulation_id, simulation_details) -> ProgressTask:
 
         details = json.loads(simulation_details)
         if len(details["name"]) > MAX_LEN_NAME:
@@ -267,7 +250,9 @@ class ActiveSimulations:
         is_live = int(details["duration"]) == 3153600000
         if is_live:
             dt = parser.parse(details["date_created"])
-            name = f"{name} | {dt.strftime('%Y-%m-%d %H:%M')} [bold red][LIVE][/bold red]"
+            name = (
+                f"{name} | {dt.strftime('%Y-%m-%d %H:%M')} [bold red][LIVE][/bold red]"
+            )
         sim_progress = details["progress"]
         return ProgressTask(
             sim_id=simulation_id,
