@@ -1,8 +1,7 @@
+from threedi_api_client.openapi.api.v3_api import V3Api
 from .base import EventWrapper
-from openapi_client import SimulationsApi
-from openapi_client import ThreedimodelsApi
 from typing import Dict
-from openapi_client.models import RasterEdit
+from threedi_api_client.openapi.models import RasterEdit
 
 
 class RasterEditError(Exception):
@@ -10,7 +9,6 @@ class RasterEditError(Exception):
 
 
 class RasterEditWrapper(EventWrapper):
-    api_class = SimulationsApi
     model = RasterEdit
     api_path: str = "raster_edits"
     scenario_name = "rasteredit"
@@ -26,14 +24,13 @@ class RasterEditWrapper(EventWrapper):
 
         if self.raster_type is not None:
             # Try to lookup/find the raster.
-            api = ThreedimodelsApi(self._api_client)
+            api: V3Api = self._api_client
             res = api.threedimodels_rasters_list(
                 self.simulation.threedimodel, type=self.raster_type
             )
             if res.count != 1:
                 raise RasterEditError(
-                    f"Could not find raster_type, raster_list "
-                    f"response whas {res}"
+                    f"Could not find raster_type, raster_list " f"response whas {res}"
                 )
 
             # Set raster
