@@ -3,10 +3,10 @@ from functools import cached_property
 from pathlib import Path
 from typing import Dict, List, Any
 
-from openapi_client.models import Simulation
+from threedi_api_client.openapi.models import Simulation
 from threedi_api_client.openapi.models import Schematisation
 from threedi_api_client.openapi.api import V3Api
-from openapi_client.exceptions import ApiException
+from threedi_api_client.openapi.exceptions import ApiException
 from threedi_api_client.threedi_api_client import ThreediApiClient
 
 from .base import SimulationWrapper, ModelWrapper, BaseWrapper
@@ -25,10 +25,9 @@ class ResolveError(Exception):
     pass
 
 
-
 class Scenario:
     base_object: Any = None
-    steps: Any = []   
+    steps: Any = []
 
     # Internal instances administration
     _refs: Dict = None
@@ -90,7 +89,7 @@ class Scenario:
                 self.threedi_api_client,
                 base_path=self._base_path,
                 refs=self._refs,
-                **self.instance_kwargs
+                **self.instance_kwargs,
             )
             steps.append(wrapped_instance)
         return steps
@@ -131,9 +130,7 @@ class Scenario:
             self.websocket_client.listen(self.websocket_endpoint_uri)
         )
         try:
-            await asyncio.wait_for(
-                self.websocket_client.is_connected(), timeout=10
-            )
+            await asyncio.wait_for(self.websocket_client.is_connected(), timeout=10)
         except asyncio.TimeoutError:
             console.print(
                 "Could not establish WebSocket connection within 10 seconds",
@@ -155,7 +152,6 @@ class Scenario:
                 raise result.exception()
 
 
-
 class SimulationScenario(Scenario):
     base_object: Simulation = None
 
@@ -171,17 +167,17 @@ class SimulationScenario(Scenario):
 
     def create_base_object(self, scenario: Dict):
         simulation_data = scenario.get("simulation")
-        self.base_object = SimulationWrapper(
-            simulation_data, self.threedi_api_client
-        )
+        self.base_object = SimulationWrapper(simulation_data, self.threedi_api_client)
 
     @property
     def websocket_endpoint_uri(self):
-        return f"simulations/{self.simulation.instance.id}/?scenario_test_framework=true"
+        return (
+            f"simulations/{self.simulation.instance.id}/?scenario_test_framework=true"
+        )
 
     @property
     def instance_kwargs(self):
-        return {'simulation': self.simulation.instance}
+        return {"simulation": self.simulation.instance}
 
     def shutdown_simulation(self):
         console.print("• Requesting simulation shutdown")
@@ -214,4 +210,4 @@ class SchematisationScenario(Scenario):
 
     @property
     def instance_kwargs(self):
-        return {'schematisation': self.schematisation.instance}
+        return {"schematisation": self.schematisation.instance}
