@@ -1,6 +1,5 @@
 from .base import EventWrapper
-from openapi_client import SimulationsApi
-from openapi_client.models import TimedStructureControl
+from threedi_api_client.openapi.models import TimedStructureControl
 
 from threedi_cmd.models.waitfor import (
     WaitForEventValidation,
@@ -9,7 +8,6 @@ from threedi_cmd.models.waitfor import (
 
 
 class WaitForStructureControlWrapper(WaitForEventValidation):
-    api_class = SimulationsApi
     model = TimedStructureControl
     scenario_name = "waitforstructurecontrol"
 
@@ -18,7 +16,6 @@ class WaitForStructureControlWrapper(WaitForEventValidation):
 
 
 class StructureControlWrapper(EventWrapper):
-    api_class = SimulationsApi
     model = TimedStructureControl
     api_path: str = "structure_control_timed"
     scenario_name = "structurecontroltimed"
